@@ -189,9 +189,11 @@ def from_dict(
     elif isinstance(clz, EnumMeta):
         return clz(value)
     elif typing.get_origin(clz) == Literal:
+        if isnamedtupleinstance(value) and len(value._fields) == 0:
+            value = value.__class__.__name__
         args = typing.get_args(clz)
         if value not in args:
-            raise ValueError(f"{value} must be one of {args}")
+            raise ValueError(f"{fpath} must be one of {args} but got '{value}'.")
         return value  # type: ignore
     if isnamedtupleinstance(value) and len(value) == 0:
         value = value.__class__.__name__
@@ -256,9 +258,13 @@ def load(
 ) -> T:
     if deserializers is None:
         deserializers = []
+    try:
+        data = pyron.load(str(file))
+    except FileNotFoundError:
+        raise FileNotFoundError(f"{file} does not exist.")
     return from_dict(
         clz,
-        pyron.load(str(file)),
+        data,
         deserializers,
         ignore_extra_fields=ignore_extra_fields,
     )
